interface RoomId {
    roomId: string;
}
interface PayloadCommon extends RoomId {
    sender: string;
    receiver: string;
}
interface PayloadOffer extends PayloadCommon {
    offer: RTCSessionDescriptionInit;
}
interface PayloadAnswer extends PayloadCommon {
    answer: RTCSessionDescriptionInit;
}
interface PayloadCandidate extends PayloadCommon {
    candidate: RTCIceCandidate;
}
declare enum Topic {
    OfferSend = "mche:offer:send",
    AnswerSend = "mche:answer:send",
    CandidateSend = "mche:candidate:send"
}
interface Payload {
    [Topic.OfferSend]: PayloadOffer;
    [Topic.AnswerSend]: PayloadAnswer;
    [Topic.CandidateSend]: PayloadCandidate;
    open: {
        data: {
            id: string;
            userData?: Record<string, unknown>;
        }[];
    } & RoomId;
    close: {
        data: {
            id: string;
        };
    } & RoomId;
}

interface MCHelperOptions {
    /**
     * The URL of the signaling server.
     * @example "wss://example.com:8080"
     */
    signalingServerUrl: string;
    /**
     * The ID of the peer.
     * If not set, will be generated using `nanoid(6)`.
     * @default nanoid(6)
     */
    id?: string;
    /**
     * Whether to print debug information.
     * - `'verbose'`: print all debug information
     * - `true`: print connection information
     *
     * @default false
     */
    debug?: boolean | 'verbose';
    /**
     * ICE servers.
     * @default
     * [
     *  { urls: 'stun:stun.l.google.com:19302', }
     * ]
     */
    iceServers?: RTCIceServer[];
    /**
     * Room id.
     *
     * Same room id will be able to communicate with each other.
     */
    roomId: string;
}
type OnJoinCallback = (data: Payload['open']['data']) => void;
type OnLeaveCallback = (data: Payload['close']['data']) => void;
declare class MCHelper<B> {
    #private;
    constructor(options: MCHelperOptions);
    get id(): string;
    broadcast(message: B): void;
    onMessageChannelReady(callback: (channel: RTCDataChannel) => void): void;
    onJoin(callback: OnJoinCallback): void;
    onLeave(callback: OnLeaveCallback): void;
    /**
     * @returns cleanup fn
     */
    onBroadcast(callback: (message: MessageEvent<B>) => void): () => void;
    close(): void;
}

export { MCHelper, type MCHelperOptions, type OnJoinCallback, type OnLeaveCallback };
